@@ -1,4 +1,4 @@
-# Copyright (c) 2021 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2025 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt6.
 # 
@@ -16,7 +16,9 @@
 # WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 
-# Map enum member names to fully scoped names.
+# Map enum member names to fully scoped names.  Note that Designer v6.7.0 and
+# later use fully scoped enum names so this is only needed for .ui files
+# created with older versions.
 EnumMap = {
     'Qt::AlignHCenter':         'Qt::AlignmentFlag::AlignHCenter',
     'Qt::AlignJustify':         'Qt::AlignmentFlag::AlignJustify',
@@ -143,6 +145,11 @@ EnumMap = {
     'Qt::ScrollBarAlwaysOn':    'Qt::ScrollBarPolicy::ScrollBarAlwaysOn',
     'Qt::ScrollBarAsNeeded':    'Qt::ScrollBarPolicy::ScrollBarAsNeeded',
 
+    'Qt::ApplicationShortcut':          'Qt::ShortcutContext::ApplicationShortcut',
+    'Qt::WidgetShortcut':               'Qt::ShortcutContext::WidgetShortcut',
+    'Qt::WidgetWithChildrenShortcut':   'Qt::ShortcutContext::WidgetWithChildrenShortcut',
+    'Qt::WindowShortcut':               'Qt::ShortcutContext::WindowShortcut',
+
     'Qt::ElideLeft':    'Qt::TextElideMode::ElideLeft',
     'Qt::ElideRight':   'Qt::TextElideMode::ElideRight',
     'Qt::ElideMiddle':  'Qt::TextElideMode::ElideMiddle',
@@ -334,6 +341,14 @@ EnumMap = {
     'QFontDatabase::Runic':                 'QFontDatabase::WritingSystem::Runic',
     'QFontDatabase::Nko':                   'QFontDatabase::WritingSystem::Nko',
 
+    'QFormLayout::AllNonFixedFieldsGrow':   'QFormLayout::FieldGrowthPolicy::AllNonFixedFieldsGrow',
+    'QFormLayout::ExpandingFieldsGrow':     'QFormLayout::FieldGrowthPolicy::ExpandingFieldsGrow',
+    'QFormLayout::FieldsStayAtSizeHint':    'QFormLayout::FieldGrowthPolicy::FieldsStayAtSizeHint',
+
+    'QFormLayout::DontWrapRows':    'QFormLayout::RowWrapPolicy::DontWrapRows',
+    'QFormLayout::WrapLongRows':    'QFormLayout::RowWrapPolicy::WrapLongRows',
+    'QFormLayout::WrapAllRows':     'QFormLayout::RowWrapPolicy::WrapAllRows',
+
     'QFrame::Box':          'QFrame::Shape::Box',
     'QFrame::HLine':        'QFrame::Shape::HLine',
     'QFrame::NoFrame':      'QFrame::Shape::NoFrame',
